@@ -1,10 +1,5 @@
 """
-Monitor (gets all data, evaluates commandments
-stores commandment outcome and stores metrics)
-    get data
-    run rule
-        rules generate metrics (some rules are simple, some require processing)
-    store metrics
+The Monitor connects to sources, evaluates rules, sends the resulting metrics to the stores.
 """
 from collections.abc import Iterable
 from uuid import uuid4
