@@ -15,7 +15,17 @@ from typing import (
 )
 from uuid import UUID
 
-from typing_extensions import TypeAlias
+try:
+    # Version 3.10 and above:
+    from typing import TypeAlias
+except ImportError:
+    # Python 3.9 and below:
+    try:
+        from typing_extensions import TypeAlias
+    except ImportError:
+        # Don't need typing in runtime
+        TypeAlias = None  # type: ignore
+
 
 if TYPE_CHECKING:  # pragma: no cover
     from sinai.metrics import AggregationMetric, Metric  # noqa: F401
